pub enum EventSinkInactiveReason {
UnsupportedProtocolVersion {
requested: u16,
supported: u16,
},
InstallIncomplete,
PlatformIneligible,
ServiceDisabled,
ObservationPermissionNotGranted {
permission: ObservationPermissionId,
},
}Variants
UnsupportedProtocolVersion
InstallIncomplete
PlatformIneligible
ServiceDisabled
ObservationPermissionNotGranted
The manifest narrows delivery using a field that the host has not granted this sink permission to observe. Keeping the sink inactive avoids turning delivery versus non-delivery into a side channel.
Fields

permission: ObservationPermissionIdTrait Implementations
Sourceimpl Clone for EventSinkInactiveReason
impl Clone for EventSinkInactiveReason
Sourcefn clone(&self) -> EventSinkInactiveReason
fn clone(&self) -> EventSinkInactiveReason
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventSinkInactiveReason
impl Debug for EventSinkInactiveReason
Sourceimpl<'de> Deserialize<'de> for EventSinkInactiveReason
impl<'de> Deserialize<'de> for EventSinkInactiveReason
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EventSinkInactiveReason
Sourceimpl PartialEq for EventSinkInactiveReason
impl PartialEq for EventSinkInactiveReason
Sourceimpl Serialize for EventSinkInactiveReason
impl Serialize for EventSinkInactiveReason
impl StructuralPartialEq for EventSinkInactiveReason